pub struct VarBlake2b { /* private fields */ }Expand description
Blake2b instance with a variable output.
Implementations
Sourceimpl VarBlake2b
impl VarBlake2b
Sourcepub fn new_keyed(key: &[u8], output_size: usize) -> VarBlake2b ⓘ
pub fn new_keyed(key: &[u8], output_size: usize) -> VarBlake2b ⓘ
Creates a new hashing context with a key.
WARNING! If you plan to use it for variable output MAC, then
make sure to compare codes in constant time! It can be done
for example by using subtle crate.
Sourcepub fn with_params(
key: &[u8],
salt: &[u8],
persona: &[u8],
output_size: usize,
) -> VarBlake2b ⓘ
pub fn with_params( key: &[u8], salt: &[u8], persona: &[u8], output_size: usize, ) -> VarBlake2b ⓘ
Creates a new hashing context with the full set of sequential-mode parameters.