Utc

Struct Utc 

pub struct Utc(/* private fields */);
Utc provides access to time functions using UTC time.

Implementations

Source

impl Utc

pub fn now() -> Utc

Create a new Utc date time from now

Examples
use fungus::prelude::*;

let time = time::Utc::now();
assert_eq!(time.format("%a %e %b %Y %r %Z"), "Sat 12 Dec 2020 04:08:15 PM UTC");
pub fn timestamp(secs: i64) -> Utc

Create a new Utc date time from a unix timestamp

Examples
use fungus::prelude::*;

let time = time::Utc::timestamp(1_607_789_295);
assert_eq!(time.format("%a %e %b %Y %r %Z"), "Sat 12 Dec 2020 04:08:15 PM UTC");
pub fn format(&self, fmt: &str) -> String

Format the time using the fmt paramaters given which follow the C strftime style formatting documented here https://man.archlinux.org/man/strftime.3